var group__PkgSTLExtensionConcepts =
[
    [ "BaseWithTimeStamp", "classBaseWithTimeStamp.html", [
      [ "Has_timestamp", "classBaseWithTimeStamp.html#a12b59a77862d15d2d75d7fabc9248020", null ],
      [ "set_time_stamp", "classBaseWithTimeStamp.html#ab586bcb065f9061e3df1a5288cd1a008", null ],
      [ "time_stamp", "classBaseWithTimeStamp.html#a1ee935c51f621677cb3c9342e20b0ff5", null ]
    ] ],
    [ "Descriptor", "classDescriptor.html", null ],
    [ "Hashable", "classHashable.html", null ],
    [ "Index", "classIndex.html", null ],
    [ "ObjectWithEraseCounter", "classObjectWithEraseCounter.html", [
      [ "erase_counter", "classObjectWithEraseCounter.html#a6d07f3c6b7440bd578f2f1759bd5e89f", null ],
      [ "increment_erase_counter", "classObjectWithEraseCounter.html#a6059f4772ba8a8cbf414a3ae7375ffc8", null ],
      [ "set_erase_counter", "classObjectWithEraseCounter.html#af0c998511a51a5a399dbb083429e6a68", null ]
    ] ],
    [ "ProjectionObject", "classProjectionObject.html", [
      [ "argument_type", "classProjectionObject.html#ab507db0cd352fd04fe7b7f92fa7bb4dd", null ],
      [ "result_type", "classProjectionObject.html#a897b5549df2ea09f3e0697e9543a680f", null ],
      [ "ProjectionObject", "classProjectionObject.html#ac7e3e8d01f446472c8135f3acbb03cbe", null ],
      [ "operator()", "classProjectionObject.html#a429df2abb3336f26397dcf8f99fb799d", null ],
      [ "operator()", "classProjectionObject.html#aa224850b85fde6e038378467bdd29602", null ]
    ] ],
    [ "SurjectiveLockDataStructure", "classSurjectiveLockDataStructure.html", [
      [ "is_locked", "classSurjectiveLockDataStructure.html#a8be4390119e3ff3c5269458ca1789bd3", null ],
      [ "is_locked_by_this_thread", "classSurjectiveLockDataStructure.html#a734a1d77fccaa9aa3fe035f504bcfedc", null ],
      [ "try_lock", "classSurjectiveLockDataStructure.html#a9e89c82fdac27fbca1c7dde34a22900d", null ],
      [ "try_lock", "classSurjectiveLockDataStructure.html#a7f449f8f7aef7991af60d7f3c56c5ece", null ],
      [ "unlock_everything_locked_by_this_thread", "classSurjectiveLockDataStructure.html#ac0a0acb5759fe2b73894defb2d63c29c", null ],
      [ "unlock_everything_locked_by_this_thread_but_one", "classSurjectiveLockDataStructure.html#a4ed08cb60942e923043c2899e3121047", null ]
    ] ]
];